import { callCloudFunction } from '../../cloud'

// 海龟汤游戏数据类型
export interface TurtleSoupGame {
  id: string;
  title: string;
  story: string;
  solution: string;
  hints: string[];
  questions: TurtleSoupQuestion[];
  // 其他海龟汤特有属性
}

export interface TurtleSoupQuestion {
  id: string;
  content: string;
  answer: string;
  askedBy: string;
  timestamp: number;
}

export interface GameResult {
  solved: boolean;
  solvedBy?: string;
  timeUsed: number;
  questionsCount: number;
  hintsUsed: number[];
}

// 海龟汤游戏相关API
export const turtleSoupAPI = {
  /**
   * 获取游戏数据
   * @param gameId 游戏ID
   * @param role 用户角色
   */
  getGameData(gameId: string, role: string) {
    return callCloudFunction<{ game: TurtleSoupGame }>('getTurtleSoupGame', { gameId, role })
  },

  /**
   * 提交问题
   * @param gameId 游戏ID
   * @param content 问题内容
   */
  submitQuestion(gameId: string, content: string) {
    return callCloudFunction<{ questionId: string }>('submitTurtleSoupQuestion', { gameId, content })
  },

  /**
   * 回答问题
   * @param questionId 问题ID
   * @param answer 答案
   */
  answerQuestion(questionId: string, answer: string) {
    return callCloudFunction<{ success: boolean }>('answerTurtleSoupQuestion', { questionId, answer })
  },

  /**
   * 公开提示
   * @param gameId 游戏ID
   * @param hintIndex 提示索引
   */
  revealHint(gameId: string, hintIndex: number) {
    return callCloudFunction<{ success: boolean }>('revealTurtleSoupHint', { gameId, hintIndex })
  },

  /**
   * 结束游戏
   * @param gameId 游戏ID
   * @param result 游戏结果
   */
  endGame(gameId: string, result: { solved: boolean; solvedBy?: string }) {
    return callCloudFunction<{ gameResult: GameResult }>('endTurtleSoupGame', { gameId, result })
  }
}
