import Taro from '@tarojs/taro'

// 控制是否使用云函数(true)或mock数据(false)
const USE_CLOUD = false

// Mock用户数据
const mockUser = {
    nickname: '测试用户',
    avatar: 'https://example.com/avatar.jpg',
    openid: 'mock_openid_123456',
  }

export const userAPI = {
    async getUserInfo() {
      if (USE_CLOUD && process.env.TARO_ENV === 'weapp') {
        try {
          // 云函数实现
          const result = await Taro.cloud.callFunction({
            name: 'getUserInfo',
          })
          
          // 使用类型断言处理结果
          if (result && typeof result === 'object' && 'result' in result) {
            const cloudResult = result.result as any
            return cloudResult?.data || mockUser
          }
          return mockUser
        } catch (error) {
          console.error('获取用户信息失败:', error)
          return mockUser
        }
      } else {
        // Mock实现
        return new Promise(resolve => {
          setTimeout(() => {
            resolve(mockUser)
          }, 300)
        })
      }
    },
    
    // 新增方法：获取OpenID
    async getOpenId(code: string) {
      if (USE_CLOUD && process.env.TARO_ENV === 'weapp') {
        try {
          const result = await Taro.cloud.callFunction({
            name: 'getOpenId',
            data: { code }
          })
          
          if (result && result.result) {
            return result.result
          }
        } catch (error) {
          console.error('获取OpenID失败:', error)
        }
      }
      
      // Mock实现
      return { openid: 'mock_openid_' + Date.now() }
    }
}