import { defineStore } from 'pinia'
import { gameAPI } from '@/services/api/game'

// 游戏数据接口
export interface Game {
  id: string;
  title: string;
  image: string;
  players: string;
  duration: string;
  rating: number;
  isNew: boolean;
  isHot: boolean;
  description: string;
  rules: string;
  category: string;
  tips: string[];
  examples: {
    question: string;
    answer: string;
  }[];
}

export const useGameStore = defineStore('game', {
  state: () => ({
    games: [] as Game[],
    loading: false,
    currentGame: null as Game | null,
  }),
  
  actions: {
    // 获取游戏列表
    async fetchGames() {
      this.loading = true;
      try {
        this.games = await gameAPI.getGames();
      } catch (error) {
        console.error('获取游戏列表失败:', error);
        this.games = [];
      } finally {
        this.loading = false;
      }
    },
    
    // 获取游戏详情
    async getGameDetail(id: string) {
      try {
        // 查找本地缓存
        const game = this.games.find(game => game.id === id);
        if (game) {
          this.currentGame = game;
          return game;
        }
        
        // 如果本地没有，从API获取
        const gameData = await gameAPI.getGameDetail(id);
        if (gameData) {
          this.currentGame = gameData;
          return gameData;
        }
        
        // 如果没有找到，返回null
        this.currentGame = null;
        return null;
      } catch (error) {
        console.error('获取游戏详情失败:', error);
        this.currentGame = null;
        return null;
      }
    }
  }
}) 